@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -149,7 +149,7 @@ void Command::print_arguments(const std::string& command) {
 }
 
 void Command::show_memory_used() {
-    osmium::MemoryUsage mem;
+    const osmium::MemoryUsage mem;
     if (mem.current() > 0) {
         m_vout << "Peak memory used: " << mem.peak() << " MBytes\n";
     }
