@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -59,16 +59,15 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
     ("default-type", po::value<std::string>()->default_value("node"), "Default item type")
     ("id-file,i", po::value<std::vector<std::string>>(), "Read OSM IDs from text file")
     ("id-osm-file,I", po::value<std::vector<std::string>>(), "Read OSM IDs from OSM file")
-    ("history", "Deprecated, use --with-history instead")
     ("with-history,H", "Make it work with history files")
     ("add-referenced,r", "Recursively add referenced objects")
     ("remove-tags,t", "Remove tags from objects not explicitly requested")
     ("verbose-ids", "Print all requested and missing IDs")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -108,11 +107,6 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
         m_work_with_history = true;
     }
 
-    if (vm.count("history")) {
-        warning("The --history option is deprecated. Use --with-history instead.\n");
-        m_work_with_history = true;
-    }
-
     if (vm.count("default-type")) {
         m_default_item_type = parse_item_type(vm["default-type"].as<std::string>());
     }
@@ -188,17 +182,17 @@ void CommandGetId::show_arguments() {
     if (m_verbose_ids) {
         m_vout << "    looking for these ids:\n";
         m_vout << "      nodes:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::node)) {
+        for (const auto id : m_ids(osmium::item_type::node)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
         m_vout << "      ways:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::way)) {
+        for (const auto id : m_ids(osmium::item_type::way)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
         m_vout << "      relations:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::relation)) {
+        for (const auto id : m_ids(osmium::item_type::relation)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
@@ -236,7 +230,7 @@ static void print_missing_ids(const char* type, const osmium::index::IdSetDense<
     std::cerr << '\n';
 }
 
-void CommandGetId::mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id) {
+void CommandGetId::mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::unsigned_object_id_type parent_id) {
     rel_in_rel.for_each(parent_id, [&](osmium::unsigned_object_id_type member_id) {
         if (m_ids(osmium::item_type::relation).check_and_set(member_id)) {
             mark_rel_ids(rel_in_rel, member_id);
@@ -271,7 +265,7 @@ bool CommandGetId::find_relations_in_relations() {
     }
 
     const auto rel_in_rel = stash.build_parent_to_member_index();
-    for (const osmium::unsigned_object_id_type id : m_ids(osmium::item_type::relation)) {
+    for (const auto id : m_ids(osmium::item_type::relation)) {
         mark_rel_ids(rel_in_rel, id);
     }
 
