@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -56,9 +56,9 @@ bool CommandGetParents::setup(const std::vector<std::string>& arguments) {
     ("verbose-ids", "Print all requested IDs")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -153,17 +153,17 @@ void CommandGetParents::show_arguments() {
     if (m_verbose_ids) {
         m_vout << "    looking for these ids:\n";
         m_vout << "      nodes:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::node)) {
+        for (const auto id : m_ids(osmium::item_type::node)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
         m_vout << "      ways:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::way)) {
+        for (const auto id : m_ids(osmium::item_type::way)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
         m_vout << "      relations:";
-        for (osmium::object_id_type id : m_ids(osmium::item_type::relation)) {
+        for (const auto id : m_ids(osmium::item_type::relation)) {
             m_vout << " " << id;
         }
         m_vout << "\n";
