@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 # include <unistd.h>
 #endif
 
@@ -37,7 +37,7 @@ bool CommandHelp::setup(const std::vector<std::string>& arguments) {
 }
 
 static void show_help(const std::string& topic, const std::string& info) {
-#ifndef _MSC_VER
+#ifndef _WIN32
     // show man page on non-Windows systems
     std::string manpage{"osmium-"};
     manpage += topic;
