@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -42,18 +42,18 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <utility>
 #include <vector>
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 # include <unistd.h>
 #endif
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 void CommandShow::setup_pager_from_env() noexcept {
     m_pager = "less";
-    const char* pager = ::getenv("OSMIUM_PAGER");
+    const char* pager = ::getenv("OSMIUM_PAGER"); // NOLINT(concurrency-mt-unsafe)
     if (pager) {
         m_pager = pager;
     } else {
-        pager = ::getenv("PAGER");
+        pager = ::getenv("PAGER"); // NOLINT(concurrency-mt-unsafe)
         if (pager) {
             m_pager = pager;
         }
@@ -71,15 +71,15 @@ bool CommandShow::setup(const std::vector<std::string>& arguments) {
     ("format-debug,d", "Use debug format")
     ("format-opl,o", "Use OPL format")
     ("format-xml,x", "Use XML format")
-#ifndef _MSC_VER
+#ifndef _WIN32
     ("no-pager", "Do not run pager program")
 #endif
     ("object-type,t", po::value<std::vector<std::string>>(), "Read only objects of given type (node, way, relation, changeset)")
     ("output-format,f", po::value<std::string>(), "Format of output file")
     ;
 
-    po::options_description opts_common{add_common_options(false)};
-    po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_common{add_common_options(false)};
+    const po::options_description opts_input{add_single_input_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -105,7 +105,7 @@ bool CommandShow::setup(const std::vector<std::string>& arguments) {
     setup_object_type_nwrc(vm);
     setup_input_file(vm);
 
-#ifndef _MSC_VER
+#ifndef _WIN32
     if (vm.count("no-pager")) {
         m_pager = "";
     } else {
@@ -129,7 +129,7 @@ bool CommandShow::setup(const std::vector<std::string>& arguments) {
     } else if (vm.count("format-xml")) {
         m_output_format = "xml";
     } else {
-        const char* output_format_from_env = ::getenv("OSMIUM_SHOW_FORMAT");
+        const char* output_format_from_env = ::getenv("OSMIUM_SHOW_FORMAT"); // NOLINT(concurrency-mt-unsafe)
         if (output_format_from_env) {
             m_output_format = output_format_from_env;
         }
@@ -149,7 +149,7 @@ void CommandShow::show_arguments() {
     show_object_types(m_vout);
 }
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 static int execute_pager(const std::string& pager, bool with_color) {
     int pipefd[2];
     if (::pipe(pipefd) < 0) {
@@ -190,17 +190,17 @@ static int execute_pager(const std::string& pager, bool with_color) {
 
 bool CommandShow::run() {
     osmium::io::Reader reader{m_input_file, osm_entity_bits()};
-    osmium::io::Header header{reader.header()};
+    const osmium::io::Header header{reader.header()};
 
     if (m_pager.empty()) {
-        osmium::io::File file{"-", m_output_format};
+        const osmium::io::File file{"-", m_output_format};
         osmium::io::Writer writer{file, header};
         while (osmium::memory::Buffer buffer = reader.read()) {
             writer(std::move(buffer));
         }
         writer.close();
     } else {
-#ifndef _MSC_VER
+#ifndef _WIN32
         const int fd = execute_pager(m_pager, m_color_output);
 
         if (::dup2(fd, 1) < 0) { // put end of pipe as stdout
@@ -208,7 +208,7 @@ bool CommandShow::run() {
         }
         ::close(fd);
 
-        osmium::io::File file{"-", m_output_format};
+        const osmium::io::File file{"-", m_output_format};
         osmium::io::Writer writer{file, header};
         try {
             while (osmium::memory::Buffer buffer = reader.read()) {
