@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -103,7 +103,7 @@ void with_multiple_osm_inputs::setup_input_files(const boost::program_options::v
     }
 
     for (const std::string& input_filename : m_input_filenames) {
-        osmium::io::File input_file{input_filename, m_input_format};
+        const osmium::io::File input_file{input_filename, m_input_format};
         m_input_files.push_back(input_file);
     }
 }
